]> granicus.if.org Git - mutt/commitdiff
Flag translator comments using L10N.
authorKevin McCarthy <kevin@8t8.us>
Wed, 2 Sep 2015 21:43:05 +0000 (14:43 -0700)
committerKevin McCarthy <kevin@8t8.us>
Wed, 2 Sep 2015 21:43:05 +0000 (14:43 -0700)
Add comment to devel-notes.txt documentation.

alias.c
curs_main.c
doc/devel-notes.txt
po/Makefile.in.in

diff --git a/alias.c b/alias.c
index a8fa61f750c7da472ae2198ece91e678ae2bdfdb..986f44765d205b3c0b8f7dde8df6829239d535af 100644 (file)
--- a/alias.c
+++ b/alias.c
@@ -256,7 +256,7 @@ void mutt_create_alias (ENVELOPE *cur, ADDRESS *iadr)
   mutt_check_alias_name (tmp, buf, sizeof (buf));
   
 retry_name:
-  /* add a new alias */
+  /* L10N: prompt to add a new alias */
   if (mutt_get_field (_("Alias as: "), buf, sizeof (buf), 0) != 0 || !buf[0])
     return;
 
index 8553102457bc96794c8f13cd2d580f9be0c692c4..d20028efaae6ed803595c754b29fc00bb43f2b31 100644 (file)
@@ -903,7 +903,7 @@ int mutt_index_menu (void)
        else
        {
           char buf[STRING];
/* i18n: ask for a limit to apply */
           snprintf (buf, sizeof(buf), _("Limit: %s"),Context->pattern);
            mutt_message ("%s", buf);
        }
index 82b1e0b18b0edc2cdecd26f264f3f8f9fc2dfb76..4eede0fe5ee267a8e9fffc4073afd036790795cb 100644 (file)
@@ -196,6 +196,10 @@ Style Guide
   from the times when this was an iso-8859-1 source code tree,
   please feel free to fix them.
 
+- prefix translator comments with L10N:
+  /* L10N: this is a translator comment */
+  puts(_("String to translate));
+
 Documentation
 -------------
 
index c1b0b2c7a30edec520d27823484f284737590779..4b6727c0a681f76647e7c6476a7f71ed29d7585f 100644 (file)
@@ -91,11 +91,11 @@ $(top_builddir)/keymap_alldefs.h:
 $(PACKAGE).pot: $(POTFILES) $(BUILT_POTFILES) $(srcdir)/POTFILES.in
        rm -f $(PACKAGE).pot $(PACKAGE).po
        $(XGETTEXT) --default-domain=$(PACKAGE) --directory=$(top_srcdir) \
-         --add-comments --keyword=_ --keyword=N_ \
+         --add-comments=L10N --keyword=_ --keyword=N_ \
          --files-from=$(srcdir)/POTFILES.in \
        && \
        $(XGETTEXT) --default-domain=$(PACKAGE) \
-         --add-comments --keyword=_ --keyword=N_ \
+         --add-comments=L10N --keyword=_ --keyword=N_ \
          --join $(BUILT_POTFILES) \
        && test ! -f $(PACKAGE).po \
           || ( rm -f $(PACKAGE).pot \
@@ -903,7 +903,7 @@ int mutt_index_menu (void)
        {
           char buf[STRING];
-          /* i18n: ask for a limit to apply */
+          /* L10N: ask for a limit to apply */
           snprintf (buf, sizeof(buf), _("Limit: %s"),Context->pattern);
            mutt_message ("%s", buf);